Changelog
=========

1.2
---
* Support Django 3.1 and 3.2
* Support Python 3.9 and 3.10
* Swith to GitHub Actions

1.1
---
* Support Django 2.2 and 3.0
* Support Python 3.8

1.0
---

* First release marked as stable
* Support Django 2.0 and 2.1
* Support Python 3.7

0.5
---

* Add new template tag: ``buildfullurl``
* Relicense to MIT
* Support Django 1.11

Thank you to `Jakub Dolejšek <https://github.com/x0nix>`__ for the contribution
of the new template tage ``buildfullurl``.

0.4
---

* Fix RST syntax errors in README.rst

0.3
---

* Fix and improve documentation
* Add CHANGELOG.rst to MANIFEST.in

0.2
---

* Add support for Django 1.8 and Django 1.9, in addition to Django 1.10.
* Add support for Python 2.7, Python 3.2, 3.3, 3.4 and 3.5, in addition to Python 3.6.

0.1
---

* First release on PyPI.
